@@ -79,6 +79,7 @@ function getLinkSortOrder($lid)
 // avddelete()
 function avddelete($file)
 {
+    $file = html_entity_decode($file, ENT_QUOTES);
     chmod($file,0777);
     if (@is_dir($file))
     {
@@ -991,7 +992,7 @@ function GetRSSLinks()
 
 // ***************************************************************************
 // Build Search Engine Drop Down List
-function buildSearchEngineDDL($selectedEngine = 'TorrentSpy', $autoSubmit = false)
+function buildSearchEngineDDL($selectedEngine = 'PirateBay', $autoSubmit = false)
 {
     $output = "<select name=\"searchEngine\" ";
     if ($autoSubmit)
@@ -1028,7 +1029,7 @@ function buildSearchEngineDDL($selectedEngine = 'TorrentSpy', $autoSubmit = fals
 
 // ***************************************************************************
 // Build Search Engine Links
-function buildSearchEngineLinks($selectedEngine = 'TorrentSpy')
+function buildSearchEngineLinks($selectedEngine = 'PirateBay')
 {
     global $cfg;
 
@@ -1494,14 +1495,7 @@ function cleanFileName($inName)
 // returns true if client is tornado
 function usingTornado()
 {
-    global $cfg;
-    $rtnValue = false;
-    if (preg_match("/btphptornado/i", $cfg["btphpbin"]))
-    {
-        $rtnValue = true;
-    }
-
-    return $rtnValue;
+    return true;
 }
 
 //**************************************************************************
@@ -1954,7 +1948,7 @@ function runPS()
 {
     global $cfg;
 
-    return shell_exec("ps x -o pid='' -o ppid='' -o command='' -ww | grep btphptornado | grep ".$cfg["torrent_file_path"]." | grep -v grep");
+    return shell_exec("ps x -o pid='' -o ppid='' -o command='' -ww | grep ".basename($cfg["btphpbin"])." | grep ".$cfg["torrent_file_path"]." | grep -v grep");
 }
 
 //**************************************************************************
@@ -1991,7 +1985,7 @@ function RunningProcessInfo()
             }
             else
             {
-               if(strpos($arScreen[$i], "btphptornado.py") !== false)
+               if(strpos($arScreen[$i], basename($cfg["btphpbin"])) !== false)
                {
                    $pinfo = new ProcessInfo($arScreen[$i]);
 
@@ -2098,7 +2092,7 @@ function getRunningTorrents()
     {
         if(! strpos($arScreen[$i], $cfg["tfQManager"]) > 0)
         {
-           if(strpos($arScreen[$i], "btphptornado.py") !== false)
+           if(strpos($arScreen[$i], basename($cfg["btphpbin"])) !== false)
            {
                $pinfo = new ProcessInfo($arScreen[$i]);
 
