@@ -70,17 +70,17 @@
 
     // Variable information
     $tpath    = $cfg["torrent_file_path"];
-    $tfile    = $_POST['torrent'];
-    $file     = $_GET['path'];
+    $tfile    = getRequestVar('torrent');
+    $file     = getRequestVar('path');
     $torrent  = cleanFileName(StripFolders( trim($file) )) . ".torrent";
-    $announce = ( $_POST['announce'] ) ? $_POST['announce'] : "http://";
-    $ancelist = $_POST['announcelist'];
-    $comment  = $_POST['comments'];
-    $peice    = $_POST['piecesize'];
-    $alert    = ( $_POST['alert'] ) ? 1 : "''";
-    $private  = ( $_POST['Private'] == "Private" ) ? true : false;
-    $dht      = ( $_POST['DHT'] == "DHT" ) ? true : false;
-    
+    $announce = ( getRequestVar('announce') ) ? getRequestVar('announce') : "http://";
+    $ancelist = getRequestVar('announcelist');
+    $comment  = getRequestVar('comments');
+    $peice    = getRequestVar('piecesize');
+    $alert    = ( getRequestVar('alert') ) ? 1 : "''";
+    $private  = ( getRequestVar('Private') == "Private" ) ? true : false;
+    $dht      = ( getRequestVar('DHT') == "DHT" ) ? true : false;
+
     // Let's create the torrent
     if( !empty( $announce ) && $announce != "http://" )
     {
@@ -89,16 +89,16 @@
         {
             @mkdir( $tpath );
         }
-        
+
         // Clean up old files
         if( @file_exists( $tpath . $tfile ) )
         {
             @unlink( $tpath . $tfile );
         }
-        
+
         // This is the command to execute
-        $app = "nohup " . $cfg["pythonCmd"] . " -OO " . $cfg["btmakemetafile"] . " " . $announce . " " . escapeshellarg( $cfg['path'] . $file ) . " ";
-        
+        $app = "nohup " . $cfg["pythonCmd"] . " -OO " . $cfg["btmakemetafile"] . " " . escapeshellarg($announce) . " " . escapeshellarg( $cfg['path'] . $file ) . " ";
+
         // Is there comments to add?
         if( !empty( $comment ) )
         {
@@ -108,7 +108,7 @@
         // Set the piece size
         if( !empty( $peice ) )
         {
-            $app .= "--piece_size_pow2 " . $peice . " ";
+            $app .= "--piece_size_pow2 " . escapeshellarg( $peice ) . " ";
         }
 
         if( !empty( $ancelist ) )
@@ -123,10 +123,10 @@
 
         // Set the target torrent fiel
         $app .= "--target " . escapeshellarg( $tpath . $tfile );
-        
+
         // Set to never timeout for large torrents
         set_time_limit( 0 );
-        
+
         // Let's see how long this takes...
         $time_start = microtime( true );
 
@@ -140,7 +140,7 @@
         {
             // This means it is a valid torrent
             $success = true;
-            
+
             // Make an entry for the owner
             AuditAction($cfg["constants"]["file_upload"], $tfile);
 
@@ -158,7 +158,7 @@
                     @fseek( $fp, $pos, SEEK_SET );
                     if( $private )
                     {
-                        @fwrite( $fp, "7:privatei1e17:dht_backup_enablei0e20:dht_backup_requestedi0eee" );
+                        @fwrite( $fp, "7:privatei1eee" );
                     }
                     else
                     {
@@ -196,10 +196,10 @@
     }
 
     // This is the torrent download prompt
-    if( !empty( $_GET["download"] ) )
+    if( isset( $_REQUEST["download"] ) )
     {
-        $tfile = $_GET["download"];
-        
+        $tfile = getRequestVar("download");
+
         // ../ is not allowed in the file name
         if (!ereg("(\.\.\/)", $tfile))
         {
@@ -211,12 +211,12 @@
                 header( "Content-disposition: attachment; filename=\"" . $tfile . "\"\n" );
                 header( "Content-transfer-encoding: binary\n");
                 header( "Content-length: " . @filesize( $tpath . $tfile ) . "\n" );
-                
+
                 // Send the torrent file
                 $fp = @fopen( $tpath . $tfile, "r" );
                 @fpassthru( $fp );
                 @fclose( $fp );
-                
+
                 AuditAction($cfg["constants"]["fm_download"], $tfile);
             }
             else
@@ -230,7 +230,7 @@
         }
         exit();
     }
-    
+
     // Strip the folders from the path
     function StripFolders( $path )
     {
@@ -242,7 +242,7 @@
     // Convert a timestamp to a duration string
     function duration( $timestamp )
     {
-        
+
         $years = floor( $timestamp / ( 60 * 60 * 24 * 365 ) );
         $timestamp %= 60 * 60 * 24 * 365;
 
@@ -257,7 +257,7 @@
 
         $mins = floor( $timestamp / 60 );
         $secs = $timestamp % 60;
-       
+
         $str = "";
 
         if( $years >= 1 )
@@ -280,7 +280,7 @@
 <html>
 <HEAD>
     <META HTTP-EQUIV="Content-Type" CONTENT="text/html; charset=iso-8859-1" />
-    <META HTTP-EQUIV="Pragma" CONTENT="no-cache; charset=<?php echo _CHARSET ?>" />
+    <META HTTP-EQUIV="Pragma" CONTENT="no-cache" charset="<?php echo _CHARSET ?>">
     <TITLE><?php echo $cfg["pagetitle"]; ?> - Torrent Maker</TITLE>
     <LINK REL="icon" HREF="images/favicon.ico" TYPE="image/x-icon" />
     <LINK REL="shortcut icon" HREF="images/favicon.ico" TYPE="image/x-icon" />
@@ -469,14 +469,12 @@
                                                 <tr>
                                                     <td><img align="absmiddle" src="images/info.gif" onmouseover="return escape(piece);" hspace="1" />Piece size:</td>
                                                     <td><select id="piecesize" name="piecesize">
+                                                        <!-- <option id="0" value="0" selected>0 (Auto)</option> -->
                                                         <option id="0" value="0" selected>0 (Auto)</option>
-                                                        <!-- Removed for now as it doesn't seem to be working with creating torrents (??) -->
-                                                        <!--
-                                                        <option id="256" value="256">256</option>
-                                                        <option id="512" value="512">512</option>
-                                                        <option id="1024" value="1024">1024</option>
-                                                        <option id="2048" value="2048">2048</option>
-                                                        -->
+                                                        <option id="256" value="18">256</option>
+                                                        <option id="512" value="19">512</option>
+                                                        <option id="1024" value="20">1024</option>
+                                                        <option id="2048" value="21">2048</option>
                                                     </select> bytes</td>
                                                 </tr>
                                                 <tr>
@@ -501,7 +499,7 @@
                                                         <input type="button" id="Cancel" name="close" value="Close" onClick="window.close();" />
                                                         <label for="alert" title="Send alert message box when torrent has been completed.">
                                                             <input type="checkbox" id="alert" name="alert"<?php echo ( $alert != "''" ) ? " checked" : ""; ?> value="AlertMe" />
-                                                            Notify me of completion 
+                                                            Notify me of completion
                                                         </label>
                                                     </td>
                                                 </tr>
@@ -520,8 +518,8 @@
                         </td>
                     </tr>
                 </table>
-<?php 
-                DisplayTorrentFluxLink(); 
+<?php
+                DisplayTorrentFluxLink();
 ?>
             </td>
         </tr>
