@@ -290,7 +290,7 @@ function ShowCookies()
     global $cfg, $db;
     DisplayHead($cfg["user"] . "'s "._PROFILE);
 
-    $cid = $_GET["cid"]; // Cookie ID
+    $cid = getRequestVar("cid"); // Cookie ID
 
     // Used for when editing a cookie
     $hostvalue = $datavalue = "";
@@ -305,7 +305,7 @@ function ShowCookies()
 ?>
 <SCRIPT LANGUAGE="JavaScript">
     <!-- Begin
-    function popUp(name_file) 
+    function popUp(name_file)
     {
         window.open (name_file,'help','toolbar=no,location=no,directories=no,status=no,menubar=no,scrollbars=yes,resizable=no,width=800,height=600')
     }
@@ -371,8 +371,7 @@ function ShowCookies()
                     </tr>
 <?php
         // Output the list of cookies in the database
-        $sql = "SELECT c.cid, c.host, c.data FROM tf_cookies AS c, tf_users AS u WHERE u.uid=c.uid AND u.user_id='" . $cfg["user"] . "'";
-        $dat = $db->GetAll( $sql );
+        $dat = getAllCookies($cfg["user"]);
         if( empty( $dat ) )
         {
 ?>
@@ -401,7 +400,7 @@ function ShowCookies()
                 </table>
             </td>
         </tr>
-<?php    
+<?php
     }
 ?>
         <tr>
@@ -429,7 +428,7 @@ function addCookie( $newCookie )
 {
     if( !empty( $newCookie ) )
     {
-        global $cfg; 
+        global $cfg;
         AddCookieInfo( $newCookie );
         AuditAction( $cfg["constants"]["admin"], "New Cookie: " . $newCookie["host"] . " | " . $newCookie["data"] );
     }
@@ -485,7 +484,7 @@ switch ($op)
     break;
 
     // Show main Cookie Management
-    case "showCookies": 
+    case "showCookies":
     case "editCookies":
         showCookies();
     break;
@@ -507,7 +506,7 @@ switch ($op)
 
     // Delete selected cookie from user
     case "deleteCookie":
-        $cid = $_GET["cid"];
+        $cid = getRequestVar("cid");
         deleteCookie( $cid );
     break;
 
